@@ -4,10 +4,9 @@ import pathlib
 
 import pytest
 
-from libvcs.cmd.core import which
+from libvcs._internal.run import which
 from libvcs.conftest import CreateProjectCallbackFixtureProtocol
 from libvcs.projects.svn import SubversionProject
-from libvcs.shortcuts import create_project_from_pip_url
 
 if not which("svn"):
     pytestmark = pytest.mark.skip(reason="svn is not available")
@@ -16,11 +15,9 @@ if not which("svn"):
 def test_repo_svn(tmp_path: pathlib.Path, svn_remote_repo):
     repo_name = "my_svn_project"
 
-    svn_repo = create_project_from_pip_url(
-        **{
-            "pip_url": f"svn+file://{svn_remote_repo}",
-            "dir": tmp_path / repo_name,
-        }
+    svn_repo = SubversionProject(
+        url=f"file://{svn_remote_repo}",
+        dir=str(tmp_path / repo_name),
     )
 
     svn_repo.obtain()
